/*
 * Copyright 2008 Kyoto University and Honda Motor Co.,Ltd.
 * All rights reserved.
 * HARK was developed by researchers in Okuno Laboratory
 * at the Kyoto University and Honda Research Institute Japan Co.,Ltd.
 */


/*
 * constants.hpp
 *
 *  Created on: 2010/11/08
 *      Author: HARK Development Team
 *
 * #define を使わずに数学定数など、各種定数を定義する
 */

#ifndef CONSTANTS_HPP_
#define CONSTANTS_HPP_

/**
 * @file constants.hpp
 * 各種定数の定義.
 * define を使った従来の数学定数の定義に代わり、
 * static const変数を用いた定義を提供する
 */

// constants.hppをインクルードした後にcmathやmath.hをインクルードすると
// 定数の定義がおかしくなるので、事前にインクルードしておく
#include <cmath>

#ifdef M_PI
#undef M_PI
#endif

#ifdef M_PI_2
#undef M_PI_2
#endif

#ifdef M_PI_4
#undef M_PI_4
#endif

#ifdef M_1_PI
#undef M_1_PI
#endif

#ifdef M_2_PI
#undef M_2_PI
#endif

#ifdef M_2_SQRTPI
#undef M_2_SQRTPI
#endif

#ifdef M_E
#undef M_E
#endif

#ifdef M_LOG2E
#undef M_LOG2E
#endif

#ifdef M_LOG10E
#undef M_LOG10E
#endif

#ifdef M_LN2
#undef M_LN2
#endif

#ifdef M_LN10
#undef M_LN10
#endif

#ifdef M_SQRT2
#undef M_SQRT2
#endif

#ifdef M_SQRT1_2
#undef M_SQRT1_2
#endif

static const double M_PI = 3.14159265358979323846;
static const double M_PI_2 = 1.57079632679489661923;
static const double M_PI_4 = 0.78539816339744830962;
static const double M_1_PI = 0.31830988618379067154;
static const double M_2_PI = 0.63661977236758134308;
static const double M_2_SQRTPI = 1.12837916709551257390;
static const double M_E = 2.7182818284590452354;
static const double M_LOG2E = 1.4426950408889634074;
static const double M_LOG10E = 0.43429448190325182765;
static const double M_LN2 = 0.69314718055994530942;
static const double M_LN10 = 2.30258509299404568402;
static const double M_SQRT2 = 1.41421356237309504880;
static const double M_SQRT1_2 = 0.70710678118654752440;

namespace NSHarkBinaural
{

/**
 * さまざまな数学定数を集めた構造体
 */
struct Constants
{
    static const double ConstPi = 3.14159265358979323846;
    static const double ConstPi2 = 1.57079632679489661923;
    static const double ConstPi4 = 0.78539816339744830962;
    static const double Const1Pi = 0.31830988618379067154;
    static const double Const2Pi = 0.63661977236758134308;
    static const double Const2SqrtPi = 1.12837916709551257390;
    static const double ConstE = 2.7182818284590452354;
    static const double ConstLog2e = 1.4426950408889634074;
    static const double ConstLog10e = 0.43429448190325182765;
    static const double ConstLn2 = 0.69314718055994530942;
    static const double ConstLn10 = 2.30258509299404568402;
    static const double ConstSqrt2 = 1.41421356237309504880;
    static const double ConstSqrt1_2 = 0.70710678118654752440;
};

}

#endif /* CONSTANTS_HPP_ */
